[Laszlo-checkins] r14184 - openlaszlo/trunk/WEB-INF/lps/lfc/kernel/dhtml

pbr@openlaszlo.org pbr at openlaszlo.org
Wed Jun 17 20:01:46 PDT 2009


Author: pbr
Date: 2009-06-17 20:01:45 -0700 (Wed, 17 Jun 2009)
New Revision: 14184

Modified:
   openlaszlo/trunk/WEB-INF/lps/lfc/kernel/dhtml/LzSprite.js
Log:
Change 20090617-Philip-0 by Philip at Philip-DC on 2009-06-17 20:14:41 EDT
    in /cygdrive/f/laszlo/svn/src/svn/openlaszlo/trunk
    for http://svn.openlaszlo.org/openlaszlo/trunk

Summary: IE7 - Fixed display of vertical scrollbars

New Features:

Bugs Fixed: LPP-8257

Technical Reviewer: max
QA Reviewer: hqm
Doc Reviewer: (pending)

Documentation:

Release Notes:
This changeset turns off the quirk added in LPP-3691. With this turned off, the scrollbars work the same as FF3. I added overflow:hidden to lzinputtextmultilinecontainer_click (Henry found it was missing). I also changed scrollbar_width from 16 to 17 pixels after verifying the scroll bar is 17 pixels. I used a couple of methods to determine the width, but this was the shortest (it uses jquery):
http://jdsharp.us/jQuery/minute/calculate-scrollbar-width.php

Details:
Two tests in LPP-8257 work the same in IE6/IE7/IE8 as FF3.
Tests in LPP-3691 work fine in IE6/IE7/IE8

Tests:

Files:
M      WEB-INF/lps/lfc/kernel/dhtml/LzSprite.js

Changeset: http://svn.openlaszlo.org/openlaszlo/patches/20090617-Philip-0.tar

Modified: openlaszlo/trunk/WEB-INF/lps/lfc/kernel/dhtml/LzSprite.js
===================================================================
--- openlaszlo/trunk/WEB-INF/lps/lfc/kernel/dhtml/LzSprite.js	2009-06-18 01:10:16 UTC (rev 14183)
+++ openlaszlo/trunk/WEB-INF/lps/lfc/kernel/dhtml/LzSprite.js	2009-06-18 03:01:45 UTC (rev 14184)
@@ -294,6 +294,7 @@
     // TODO [hqm 2009-04] This is a duplicate of lzinputtextmultilinecontainer (see above)
     lzinputtextmultilinecontainer_click: {
         position: 'absolute',
+        overflow: 'hidden',
         paddingTop: '1px',
         paddingRight: '3px',
         paddingBottom: '3px',
@@ -590,7 +591,8 @@
             quirks['inner_html_no_entity_apos'] = true;
 
             // workaround for IE not supporting clip in divs containing inputtext
-            quirks['inputtext_parents_cannot_contain_clip'] = true;
+            // Turning this off fixes LPP-8257
+            //quirks['inputtext_parents_cannot_contain_clip'] = true;
 
             // flag for components (basefocusview for now) to minimize opacity changes
             this.capabilities['minimize_opacity_changes'] = true;
@@ -622,8 +624,8 @@
             quirks['focus_on_mouseover'] = false;
             // required for text-align / text-indent to work
             quirks['textstyle_on_textdiv'] = true;
-            // IE scrollbar is 16px
-            quirks['scrollbar_width'] = 16;
+            // IE scrollbar is 17px
+            quirks['scrollbar_width'] = 17;
             // CSS sprites conflict with ie_alpha_image_loader...
             quirks['use_css_sprites'] = ! quirks['ie_alpha_image_loader'];
             // IE needs help focusing when an lztext is in the same area - LPP-8219



More information about the Laszlo-checkins mailing list